/*
 * Copyright 2013 MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <bson/bson.h>

#include "TestSuite.h"


static void
test1 (void)
{
   int32_t v = 0;

   BSON_ASSERT (bson_atomic_int_add (&v, 1) == 1);
   BSON_ASSERT (v == 1);
}


static void
test2 (void)
{
   int64_t v = 0;

   BSON_ASSERT (bson_atomic_int64_add (&v, 1) == 1);
   BSON_ASSERT (v == 1);
}


static void
test3 (void)
{
   bson_memory_barrier ();
}


void
test_atomic_install (TestSuite *suite)
{
   TestSuite_Add (suite, "/atomic/int/add", test1);
   TestSuite_Add (suite, "/atomic/int64/add", test2);
   TestSuite_Add (suite, "/atomic/memory_barrier", test3);
}
